OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} är tillgänglig. Få mer information om hur du uppdaterar.",
    "Updater" : "Uppdaterare",
    "For security reasons the built-in ownCloud updater is using additional credentials. To visit the updater page please click the following button." : "Utav säkerhetsskäl använder den inbyggda ownCloud-uppdateraren ytterligare inlogginingsiformation. För att öppna sidan för uppdatering vänligen tryck på följande knapp.",
    "Open updater" : "Öppna uppdateraren",
    "A new version is available: %s" : "En ny version är tillgänglig: %s",
    "Checked on %s" : "Senast kontrollerad %s",
    "Updated channel" : "Uppdaterad kanal"
},
"nplurals=2; plural=(n != 1);");
